<?php
/**
 * @author Juan Haro <juanharo@gmail.com>
 * @link http://jharo.net/dokuwiki/testmaker
 * @copyright Copyright 2012 Juan Haro
 * @license http://www.opensource.org/licenses/mit-license.php MIT License
 */
include_once "Form.php";
include_once "utils/LoadForm.php";
include_once "utils/LoadFormCache.php";
include_once 'utils/error_register.php';
include_once "utils/access.php";

/**
 * Este archivo automatiza la carga de un cuestionario.
 * Carga el cuestionario con el nombre especificado en el 
 * parametro GET 'cuestionario'
 * Uso: url?index.php?cuestionario=nombre_archivo
 */
if (!isset($_GET["cuestionario"])) {
    include("home.php");
    die("<div class='warning'>No se ha especificado un nombre de cuestionario. Para cargar un cuestionario a partir
        de un archivo de cuestionario utiliza el siguiente enlace: index.php?cuestionario=nombre_cuestionario. 
        Recuerda que nombre_cuestionario es el nombre del archivo de cuestionario
        sin incluir la extensión .yml.</div>");
}


try {
    $fileName = $_GET[CUESTIONARIO_GET_VAR];
    $loader = loadForm::getInstance($fileName);
    $loader->getHTML();
    accessRegister($fileName);
} catch (Exception $e) {
    switch ($e->getCode()) {
        case FORM_NOT_FOUND:
            echo $e->getMessage();
            break;
        case NO_READABLE_FORM_DIR:
            break;
        case CACHE_CREATION_FAIL:
            // Forzar la carga del formulario (TRUE), sin acceder a la caché
            $loader = loadForm::getInstance($fileName, TRUE);
            $loader->getHTML();
            break;
    }
    errorRegister($e->getMessage());
    sendErrorToMail($e->getMessage());
}
?>

